@@ -4,7 +4,7 @@ from fms import settings
 from fms.pb import fms_pb2 as pb, fms_pb2_grpc
 from grpc_health.v1 import health_pb2, health_pb2_grpc
 
-logger = structlog.getLogger("client")
+logger = structlog.getLogger(__name__)
 
 
 def health_check():
@@ -21,9 +21,11 @@ class FMSError(Exception):
 
 
 class FMSClient:
-    def __init__(self, raise_exception=False):
+    def __init__(self, raise_exception=False, timeout=10):
         self.client = fms_pb2_grpc.MessagingServiceAPIStub(grpc.insecure_channel(settings.MS_SERVER_URL))
         self.raise_exception = raise_exception
+        self.timeout = timeout
+        self.log = logger
 
     @classmethod
     def _build_message(
@@ -67,7 +69,7 @@ class FMSClient:
         )
 
     def _handle_error(self, message, code=""):
-        logger.error(message)
+        self.log.error(code=code, status=message)
         if self.raise_exception:
             raise FMSError(code, message)
         return None
@@ -89,6 +91,25 @@ class FMSClient:
         start_time=None,
         ttl=30,
     ):
+        self.log = self.log.bind(
+            message={
+                str(recipients),
+                text,
+                uid,
+                tag,
+                method,
+                provider,
+                alpha_name,
+                topic,
+                title,
+                action,
+                data,
+                image,
+                start_time,
+                ttl,
+            }
+        )
+
         message = self._build_message(
             recipients,
             text,
@@ -106,14 +127,20 @@ class FMSClient:
             ttl=ttl,
         )
         try:
-            response = self.client.Send(pb.MessageRequest(message=message))
+            response = self.client.Send(pb.MessageRequest(message=message), timeout=self.timeout)
         except grpc.RpcError as e:
             return self._handle_error(f"RPC call failed: {e}")
         except Exception as e:
             return self._handle_error(f"RPC call failed: {e}")
         if response.error.code:
             return self._handle_error(message=response.error.message, code=response.error.code)
-        return response.message_id
+
+        result = [
+            {"code": res.code, "status": res.status, "recipient": res.recipient, "message_id": res.message_id}
+            for res in response.results
+        ]
+        self.log.info(result=result)
+        return result
 
 
 __all__ = ["FMSError", "FMSClient", "health_check"]
